@@ -1,33 +1,26 @@
 #! /bin/false
 
 # vim: tabstop=4
-# $Id: gettext_pp.pm,v 1.21 2003/09/04 16:05:20 ingrid Exp $
+# $Id: gettext_pp.pm,v 1.23 2003/09/10 17:03:33 guido Exp $
 
 # Pure Perl implementation of Uniforum message translation.
 # Copyright (C) 2002-2003 Guido Flohr <guido@imperia.net>,
 # all rights reserved.
 
-# Distribution either under the terms of the Artistic license (see
-# Artistic) or - at your choice - under the terms and conditions of
-# the GNU General Public License described below.
-
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU Library General Public License as published
+# by the Free Software Foundation; either version 2, or (at your option)
 # any later version.
 
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
-# GNU General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Library General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-# 02111-1307, USA.
-
-# Copyright (C) 2002-2003, Guido Flohr <guido@imperia.net>
-# All rights reserved.
+# You should have received a copy of the GNU Library General Public
+# License along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+# USA.
 
 package Locale::gettext_pp;
 
@@ -649,7 +642,7 @@ __END__
 
 =head1 NAME
 
-Locale::gettext_pp - Pure Perl implementation of Uniforum Message Translation
+Locale::gettext_pp - Pure Perl Implementation of Uniforum Message Translation
 
 =head1 SYNOPSIS
 
@@ -817,7 +810,7 @@ Copyright (C) 2002-2003, Guido Flohr E<lt>guido@imperia.netE<gt>, all
 rights reserved.  See the source code for details.
 
 This software is contributed to the Perl community by Imperia 
-(http://www.imperia.net/).
+(L<http://www.imperia.net/>).
 
 =head1 SEE ALSO
 
@@ -838,16 +831,3 @@ tab-width: 4
 End:
 
 =cut
-Local Variables:
-mode: perl
-perl-indent-level: 4
-perl-continued-statement-offset: 4
-perl-continued-brace-offset: 0
-perl-brace-offset: -4
-perl-brace-imaginary-offset: 0
-perl-label-offset: -4
-cperl-indent-level: 4
-cperl-continued-statement-offset: 2
-tab-width: 4
-End:
-=cut
